summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristoph Hellwig <hch@lst.de>2026-01-07 10:26:59 +0300
committerAnna Schumaker <anna.schumaker@oracle.com>2026-01-20 22:49:46 +0300
commit0513044b749db4e20800da0c44e4299e1c7ed50a (patch)
tree003a27527d83b75801e6f785df7426cb207f71c4
parent7c80c3b8c80bc79f49c978c7d6d5166bc61816b1 (diff)
downloadlinux-0513044b749db4e20800da0c44e4299e1c7ed50a.tar.xz
NFS: drop the _locked postfix from nfs_start_delegation_return
Now that nfs_start_delegation_return_locked is gone, and we have RCU locking asserts, drop the extra postfix. Signed-off-by: Christoph Hellwig <hch@lst.de> Signed-off-by: Anna Schumaker <anna.schumaker@oracle.com>
-rw-r--r--fs/nfs/delegation.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/fs/nfs/delegation.c b/fs/nfs/delegation.c
index b90d30bf7a31..47ecf67ace91 100644
--- a/fs/nfs/delegation.c
+++ b/fs/nfs/delegation.c
@@ -315,7 +315,7 @@ static struct inode *nfs_delegation_grab_inode(struct nfs_delegation *delegation
}
static struct nfs_delegation *
-nfs_start_delegation_return_locked(struct nfs_inode *nfsi)
+nfs_start_delegation_return(struct nfs_inode *nfsi)
{
struct nfs_delegation *ret = NULL;
struct nfs_delegation *delegation;
@@ -588,7 +588,7 @@ static int nfs_end_delegation_return(struct inode *inode, struct nfs_delegation
out_return:
err = nfs_do_return_delegation(inode, delegation, issync);
out:
/* Refcount matched in nfs_start_delegation_return_locked() */
nfs_put_delegation(delegation);
return err;
}
@@ -663,7 +663,7 @@ restart:
}
}
- delegation = nfs_start_delegation_return_locked(NFS_I(inode));
+ delegation = nfs_start_delegation_return(NFS_I(inode));
rcu_read_unlock();
iput(to_put);
@@ -786,7 +786,7 @@ int nfs4_inode_return_delegation(struct inode *inode)
struct nfs_delegation *delegation;
rcu_read_lock();
- delegation = nfs_start_delegation_return_locked(nfsi);
+ delegation = nfs_start_delegation_return(nfsi);
rcu_read_unlock();
if (!delegation)
@@ -1263,13 +1263,13 @@ restart:
inode = nfs_delegation_grab_inode(delegation);
if (inode == NULL)
continue;
- delegation = nfs_start_delegation_return_locked(NFS_I(inode));
+ delegation = nfs_start_delegation_return(NFS_I(inode));
rcu_read_unlock();
if (delegation != NULL) {
if (nfs_detach_delegation(NFS_I(inode), delegation,
server) != NULL)
nfs_free_delegation(server, delegation);
- /* Match nfs_start_delegation_return_locked */
+ /* Match nfs_start_delegation_return */
nfs_put_delegation(delegation);
}
iput(inode);
@@ -588,7 +588,7 @@ static int nfs_end_delegation_return(struct inode *inode, struct nfs_delegation
err = nfs_do_return_delegation(inode, delegation, issync);
out:
- /* Refcount matched in nfs_start_delegation_return_locked() */
+ /* Refcount matched in nfs_start_delegation_return() */
nfs_put_delegation(delegation);
return err;